<?php

/**
 * Implements hook_field_formatter_settings_form().
 */
function makeupimg_field_formatter_settings_form($field, $instance, $view_mode, $form, &$form_state) {
  $settings = $instance['display'][$view_mode]['settings'];
  $element = array();

  if (module_exists('breakpoints')) {
    $breakpoints = breakpoints_breakpoint_load_all_active();
  }
  $breakpoints['default'] = array();
  foreach ($breakpoints as $breakpoint => $mediaqueries) {
    $element[$breakpoint] = array(
      '#type' => 'fieldset',
      '#title' => $breakpoint,
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $bp_list[$breakpoint] = $breakpoint;
  }
  $element['default']['#collapsed'] = FALSE;

  foreach ($breakpoints as $breakpoint => $mediaqueries) {
    $element[$breakpoint]['settings'] = array();
    $element[$breakpoint]['settings'][$breakpoint . '-sameas'] = array(
      '#title' => t("Same as"),
      '#type' => 'select',
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-sameas'],
      '#required' => FALSE,
      '#empty_option' => t("Custom"),
      '#options' => $bp_list,
    );
    $element[$breakpoint]['settings'][$breakpoint . '-selector'] = array(
      '#title' => t("Selector"),
      '#type' => 'textfield',
      '#size' => 60,
      '#maxlength' => 128,
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-selector'],
      '#required' => TRUE,
      '#description' => t("A valid CSS selector such as <code>.links > li > a, #logo</code>."),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-image_style'] = array(
      '#title' => t("Image style"),
      '#type' => 'select',
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-image_style'],
      '#required' => FALSE,
      '#empty_option' => t("None (original image)"),
      '#options' => image_style_options(FALSE),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-color'] = array(
      '#title' => t("Color"),
      '#type' => 'textfield',
      '#size' => 60,
      '#maxlength' => 128,
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-color'],
      '#required' => FALSE,
      '#description' => t("A valid CSS color value."),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-repeat'] = array(
      '#title' => t("Repeat"),
      '#type' => 'select',
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-repeat'],
      '#required' => FALSE,
      '#empty_option' => t("-No value-"),
      '#options' => array(
        'repeat' => t("Repeat horizontally and vertically"),
        'repeat-x' => t("Repeat horizontally"),
        'repeat-y' => t("Repeat vertically"),
        'no-repeat' => t("Do not repeat"),
        'inherit' => t("Inherit from parent element"),
      ),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-attachment'] = array(
      '#title' => t("Attachment"),
      '#type' => 'select',
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-attachment'],
      '#required' => FALSE,
      '#empty_option' => t("-No value-"),
      '#options' => array(
        'scroll' => t("Scroll with the page"),
        'fixed' => t("Do not scroll"),
        'local' => t("Scroll with element's contents"),
      ),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-horizontal_position'] = array(
      '#title' => t("Horizontal position"),
      '#type' => 'textfield',
      '#size' => 20,
      '#maxlength' => 20,
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-horizontal_position'],
      '#required' => FALSE,
      '#description' => t("A valid CSS horizontal position value."),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-vertical_position'] = array(
      '#title' => t("Vertical position"),
      '#type' => 'textfield',
      '#size' => 20,
      '#maxlength' => 20,
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-vertical_position'],
      '#required' => FALSE,
      '#description' => t("A valid CSS vertical position value."),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-important'] = array(
      '#title' => t("Important"),
      '#type' => 'checkbox',
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-important'],
      '#description' => t("Whenever this declaration is more important than others."),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-width'] = array(
      '#title' => t("Apply image width to the element."),
      '#type' => 'checkbox',
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-width'],
      '#description' => t("Make sure the image will be fully seen."),
    );
    $element[$breakpoint]['settings'][$breakpoint . '-height'] = array(
      '#title' => t("Apply image height to the element."),
      '#type' => 'checkbox',
      '#default_value' => $settings[$breakpoint]['settings'][$breakpoint . '-height'],
      '#description' => t("Make sure the image will be fully seen."),
    );
  }

  // Display token help field if token is enabled.
  if (module_exists('token')) {
    $element['tokens'] = array(
      '#type' => 'fieldset',
      '#title' => t("Tokens"),
      '#collapsible' => TRUE,
      '#collapsed' => TRUE,
    );
    $element['tokens']['help'] = array(
      '#theme' => 'token_tree',
      '#token_types' => array('node'),
    );
  }
  return $element;
}

/**
 * Implements hook_field_formatter_settings_summary().
 */
function makeupimg_field_formatter_settings_summary($field, $instance, $view_mode) {
  $display = $instance['display'][$view_mode];
  $settings = $display['settings'];
  $summary = array();
  if (module_exists('breakpoints')) {
    $breakpoints = breakpoints_breakpoint_load_all_active();
  }
  $breakpoints['default'] = array();
  foreach ($breakpoints as $breakpoint => $mediaqueries) {
    $summary[] = '<b>' . $breakpoint . ':</b>';
    if (isset($settings[$breakpoint]['settings'][$breakpoint . '-sameas']) && '' != $settings[$breakpoint]['settings'][$breakpoint . '-sameas']) {
      $summary[] = t("Same as") . ': ' . filter_xss_admin($settings[$breakpoint]['settings'][$breakpoint . '-sameas']);
    }
    if (!isset($settings[$breakpoint]['settings'][$breakpoint . '-sameas']) || '' == $settings[$breakpoint]['settings'][$breakpoint . '-sameas']) {
      $summary[] = t("CSS selector") . ': ' . filter_xss_admin($settings[$breakpoint]['settings'][$breakpoint . '-selector']);

      $image_styles = image_style_options(FALSE);
      // Unset possible 'No defined styles' option.
      unset($image_styles['']);
      // Styles could be lost because of enabled/disabled modules that defines
      // their styles in code.
      if (isset($image_styles[$settings[$breakpoint]['settings'][$breakpoint . '-image_style']])) {
        $summary[] = t("Image style: @style", array('@style' => $image_styles[$settings[$breakpoint]['settings'][$breakpoint . '-image_style']]));
      }
      else {
        $summary[] = t("Original image");
      }

      if ($settings[$breakpoint]['settings'][$breakpoint . '-color']) {
        $summary[] = t("Color") . ': ' . filter_xss_admin($settings[$breakpoint]['settings'][$breakpoint . '-color']);
      }
      if ($settings[$breakpoint]['settings'][$breakpoint . '-repeat']) {
        $summary[] = t("Repeat") . ': ' . filter_xss_admin($settings[$breakpoint]['settings'][$breakpoint . '-repeat']);
      }
      if ($settings[$breakpoint]['settings'][$breakpoint . '-attachment']) {
        $summary[] = t("Attachment") . ': ' . filter_xss_admin($settings[$breakpoint]['settings'][$breakpoint . '-attachment']);
      }
      // Display this setting only if horizontal or vertical position is set.
      if ($settings[$breakpoint]['settings'][$breakpoint . '-horizontal_position'] || $settings[$breakpoint]['settings'][$breakpoint . '-vertical_position']) {
        $summary[] = t("Position") . ': ' . filter_xss_admin($settings[$breakpoint]['settings'][$breakpoint . '-horizontal_position'])
                . ' - ' . filter_xss_admin($settings[$breakpoint]['settings'][$breakpoint . '-vertical_position']);
      }
      $summary[] = t("!important declaration") . ': ' . (($settings[$breakpoint]['settings'][$breakpoint . '-important']) ? t("Yes") : t("No"));
      $summary[] = t("Image width") . ': ' . (($settings[$breakpoint]['settings'][$breakpoint . '-width']) ? t("Yes") : t("No"));
      $summary[] = t("Image height") . ': ' . (($settings[$breakpoint]['settings'][$breakpoint . '-height']) ? t("Yes") : t("No"));
    }
  }

  return implode('<br />', $summary);
}

